@@ -1,6 +1,10 @@
 package Module::Install::Scripts;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
 $VERSION = '0.02';
+
 use strict;
 use File::Basename ();
 
